@@ -1,13 +1,14 @@
-from cms.plugin_base import CMSPluginBase
 from cms.plugin_pool import plugin_pool
 
+from giant_plugins.mixins import ExtendedPluginBase
+
 from . import models
 
 __all__ = ["RichTextPlugin"]
 
 
 @plugin_pool.register_plugin
-class RichTextPlugin(CMSPluginBase):
+class RichTextPlugin(ExtendedPluginBase):
     """
     Rich text plugin
     """
